sgqlc-codegen Tool
==================

.. automodule:: sgqlc.codegen
    :members:
    :special-members:
    :show-inheritance:

sgqlc-codegen Command Line Options
----------------------------------

.. argparse::
   :module: sgqlc.codegen
   :func: get_arg_parse
   :prog: sgqlc-codegen
